==> glpi_0.70.2.orig.tar.gz: glpi/front/log.php <==
<?php
/*
 * @version $Id: log.php 4892 2007-05-06 23:11:13Z moyo $
 -------------------------------------------------------------------------
 GLPI - Gestionnaire Libre de Parc Informatique
 Copyright (C) 2003-2007 by the INDEPNET Development Team.

 http://indepnet.net/   http://glpi-project.org
 -------------------------------------------------------------------------

 LICENSE

 This file is part of GLPI.

 GLPI is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 GLPI is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with GLPI; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 --------------------------------------------------------------------------
 */

// Based on:
// IRMA, Information Resource-Management and Administration
// Christian Bauer 
// ----------------------------------------------------------------------
// Original Author of file:
// Purpose of file:
// ----------------------------------------------------------------------


$NEEDED_ITEMS=array("user","tracking","computer","printer","networking","peripheral","monitor","software","phone");

define('GLPI_ROOT', '..');
include (GLPI_ROOT . "/inc/includes.php");

checkRight("logs","r");

commonHeader($LANG["title"][32],$_SERVER['PHP_SELF'],"admin","log");

//echo "<hr noshade>";

// Show last events
if(isset($_GET["order"]))
{
	if(!isset($_GET["start"])) $_GET["start"]=0;
	showEvents($_SERVER['PHP_SELF'],$_GET["order"],$_GET["sort"],$_GET["start"]);
}
else
{
	showEvents($_SERVER['PHP_SELF'],"","");
}


commonFooter();

?>

==> glpi_0.71.5.orig.tar.gz: glpi/front/log.php <==
<?php
/*
 * @version $Id: log.php 7763 2009-01-06 18:44:50Z moyo $
 -------------------------------------------------------------------------
 GLPI - Gestionnaire Libre de Parc Informatique
 Copyright (C) 2003-2009 by the INDEPNET Development Team.

 http://indepnet.net/   http://glpi-project.org
 -------------------------------------------------------------------------

 LICENSE

 This file is part of GLPI.

 GLPI is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 GLPI is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with GLPI; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 --------------------------------------------------------------------------
 */

// Based on:
// IRMA, Information Resource-Management and Administration
// Christian Bauer 
// ----------------------------------------------------------------------
// Original Author of file:
// Purpose of file:
// ----------------------------------------------------------------------


$NEEDED_ITEMS=array("user","tracking","computer","printer","networking","peripheral","monitor","software","phone");

define('GLPI_ROOT', '..');
include (GLPI_ROOT . "/inc/includes.php");

checkRight("logs","r");

commonHeader($LANG["Menu"][30],$_SERVER['PHP_SELF'],"admin","log");

//echo "<hr noshade>";

// Show last events
if(isset($_GET["order"]))
{
	if(!isset($_GET["start"])) $_GET["start"]=0;
	showEvents($_SERVER['PHP_SELF'],$_GET["order"],$_GET["sort"],$_GET["start"]);
}
else
{
	showEvents($_SERVER['PHP_SELF'],"","");
}


commonFooter();

?>
